@@ -9,8 +9,12 @@ function(object, format=c("matrix","list"), na.action, ...) {
 	# RE-CREATE OBJECTS
 	# HERE nalist INCLUDES ALL THE OBS, ALSO MISSING
 	# MISSING VALUES IN X ARE EXCLUDED IN A SECOND STAGE
-	nalist <- lapply(object$y, function(x) rep(TRUE,length(x)))
-	kXlist <- with(object,kXlistmk(X,cen,nalist,length(y),dim$k))
+	model <- object$model
+	terms <- terms(model)
+	X <- model.matrix(terms,model,object$contrast)
+	nalist <- lapply(seq(nrow(X)), function(x) rep(TRUE,length(x)))
+	kXlist <- mapply(function(i,na) {diag(1,object$dim$k)[na,,drop=FALSE]%x%
+		X[i,,drop=FALSE]},seq(nrow(X)),nalist,SIMPLIFY=FALSE)
 
 	# COMPUTE FITTED
 	fitted <- lapply(kXlist,function(kX) {
@@ -25,12 +29,9 @@ function(object, format=c("matrix","list"), na.action, ...) {
 	} else names(fitted) <- object$lab$mlab
 
 	# HANDLE MISSING
-	if(!is.null(object$X)) {Xna <- !is.na(object$X)
-	} else Xna <- as.matrix(rep(TRUE,length(object$y)))
-	nastudy <- rowSums(Xna)!=0
-	if(na.action=="na.fail" && !all(Xna)) {
-		stop("missing values in 'X'")
-	}
+	Xna <- !is.na(X)
+	nastudy <- rowSums(Xna)==object$dim$p
+	if(na.action=="na.fail" && !all(Xna)) stop("missing values in 'X'")
 	if(na.action=="na.omit") {
 		if(format=="matrix") { fitted <- fitted[nastudy,,drop=FALSE]
 		} else fitted <- fitted[nastudy]
